@@ -1,6 +1,7 @@
 """Module for loading data provider (Node) config."""
 import argparse
 import json
+import sys
 from pathlib import Path
 from typing import Optional, cast
 
@@ -21,12 +22,22 @@ class TrainingConfig(OceanConfig):
     data_type: str
     seed: int
     target_column: int
+    solo_training: bool
 
 
 class AggregationConfig(OceanConfig):
     private_key: bytes
     public_key: bytes
     download_models: bool
+    min_models: int
+
+
+def _help_exit(parser, error_msg=None):
+    """Print help of parser and quit the script."""
+    parser.print_help()
+    if error_msg:
+        print(f"\nERROR: {error_msg}")
+    sys.exit(2)
 
 
 def _add_ocean_config(config: OceanConfig) -> dict[str, str]:
@@ -80,7 +91,11 @@ def parse_training_args(args_str: Optional[list[str]] = None) -> TrainingConfig:
         Parsed args object
     """
     parser = argparse.ArgumentParser(
-        description="Script for training models, possible to execute from command line."
+        description="""
+            Script for training models, possible to execute from command line.
+            At least one of the flags --solo_training or --aggregation_key KEY must be set.
+        """,
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser = _ocean_parser(parser)
     parser.add_argument(
@@ -101,6 +116,12 @@ def parse_training_args(args_str: Optional[list[str]] = None) -> TrainingConfig:
         default=-1,
         help="Select index of target column.",
     )
+    parser.add_argument(
+        "--solo_training",
+        action="store_true",
+        default=False,
+        help="If true (flag included), it will run training on single dataset without encryption.",
+    )
     parser.add_argument(
         "--seed",
         type=int,
@@ -116,7 +137,14 @@ def parse_training_args(args_str: Optional[list[str]] = None) -> TrainingConfig:
         conf["target_column"] if "target_column" in conf else args.target_column
     )
 
-    args.aggregation_key = bytes.fromhex(args.aggregation_key)
+    if not args.solo_training and not args.aggregation_key:
+        # At least one of solo_training or aggregation_key must be set (else exit)
+        _help_exit(
+            parser, "At least one of --solo_training, --aggregation_key must be set"
+        )
+
+    if not args.solo_training:
+        args.aggregation_key = bytes.fromhex(args.aggregation_key)
 
     return cast(TrainingConfig, args)
 
@@ -132,7 +160,8 @@ def parse_aggregation_args(args_str: Optional[list[str]] = None) -> AggregationC
         Parsed args object
     """
     parser = argparse.ArgumentParser(
-        description="Script for training models, possible to execute from command line."
+        description="Script for training models, possible to execute from command line.",
+        formatter_class=argparse.ArgumentDefaultsHelpFormatter,
     )
     parser = _ocean_parser(parser)
     parser.add_argument(
@@ -146,9 +175,15 @@ def parse_aggregation_args(args_str: Optional[list[str]] = None) -> AggregationC
         help="Public key used for encrypting final model for scientis.",
         default=None,
     )
+    parser.add_argument(
+        "--min_models",
+        type=int,
+        default=2,
+        help="Minimum number of models required for aggregation (agg fails otherwise).",
+    )
     parser.add_argument(
         "--download_models",
-        help="If true, models will be donwloaded from provided URLs",
+        help="If true (flag included), models will be donwloaded from provided URLs",
         action="store_true",
         default=False,
     )
@@ -157,6 +192,10 @@ def parse_aggregation_args(args_str: Optional[list[str]] = None) -> AggregationC
     conf = _add_ocean_config(cast(OceanConfig, args))
     args.public_key = conf["public_key"] if "public_key" in conf else args.public_key
 
+    if not args.private_key:
+        # Private key is required
+        _help_exit(parser, "Private key is not defined.")
+
     args.private_key = bytes.fromhex(args.private_key)
     if args.public_key:
         args.public_key = bytes.fromhex(args.public_key)
