@@ -5,7 +5,11 @@ from sklearn.linear_model import LinearRegression
 from feltlabs.config import parse_training_args
 from feltlabs.core.data import load_data
 
-csv_data = "1,2,3\n0,2,3\n1,1,4\n0,2,5\n1,1,6"
+# Test data both with and without header
+csv_data = [
+    "column_1,col_2,c3\n1,2,3\n0,2,3\n1,1,4\n0,2,5\n1,1,6",
+    "1,2,3\n0,2,3\n1,1,4\n0,2,5\n1,1,6",
+]
 
 
 def test_csv_load(tmp_path):
@@ -13,7 +17,7 @@ def test_csv_load(tmp_path):
     for i in range(2):
         file_path = tmp_path / f"{i}"
         with open(file_path, "w") as f:
-            f.write(csv_data)
+            f.write(csv_data[i])
 
     args_str = f" --data_type csv --input_folder {tmp_path} --aggregation_key fe"
     # Define extra args with different output folder
